@@ -31,9 +31,9 @@ void printWaterBalanceResult(DataFrame DWB, List plantDWOL,
 List spwbDay(List x, CharacterVector date, double tmin, double tmax, 
              double rhmin, double rhmax, double rad, double wind, 
              double latitude, double elevation, double slope, double aspect,  
-             double prec, double runon=0.0, bool modifyInput = true);
+             double prec, double CO2 = NA_REAL, double runon=0.0, bool modifyInput = true);
 List spwbDay1(List x, NumericVector meteovec, 
-              double elevation = NA_REAL, 
+              double elevation, double slope, double aspect, 
               double runon=0.0, bool verbose=false);
 List spwbDay2(List x, NumericVector meteovec, 
               double latitude, double elevation, double slope, double aspect,
