@@ -6,6 +6,7 @@ data(SpParamsMED)
 d = 100:105
 examplesoil = soil(defaultSoilParams(4))
 
+
 test_that("Can produce all basic spwb plots and summaries",{
   control = defaultControl("Granier")
   control$verbose = FALSE
@@ -13,6 +14,7 @@ test_that("Can produce all basic spwb plots and summaries",{
   expect_s3_class(x1, "spwbInput")
   S1<-spwb(x1, examplemeteo[d,], latitude = 41.82592, elevation = 100)
   expect_s3_class(S1, "spwb")
+  expect_type(fireHazard(S1, SpParamsMED, exampleforestMED), "double")
   expect_s3_class(plot(S1, "PET_Precipitation"), "ggplot")
   expect_s3_class(plot(S1, "PET_NetRain"), "ggplot")
   expect_s3_class(plot(S1, "Snow"), "ggplot")
@@ -24,6 +26,7 @@ test_that("Can produce all basic spwb plots and summaries",{
   expect_s3_class(plot(S1, "SoilTheta"), "ggplot")
   expect_s3_class(plot(S1, "SoilVol"), "ggplot")
   expect_s3_class(plot(S1, "PlantExtraction"), "ggplot")
+  expect_s3_class(plot(S1, "HydraulicRedistribution"), "ggplot")
   expect_s3_class(plot(S1, "LAI"), "ggplot")
   expect_s3_class(plot(S1, "PlantLAI"), "ggplot")
   expect_s3_class(plot(S1, "PlantLAIlive"), "ggplot")
@@ -57,7 +60,7 @@ test_that("Can produce all advanced spwb plots and summaries",{
   expect_s3_class(x2, "spwbInput")
   S2<-spwb(x2, examplemeteo[d,], latitude = 41.82592, elevation = 100)
   expect_s3_class(S2, "spwb")
-  expect_s3_class(plot(S2, "HydraulicRedistribution"), "ggplot")
+  expect_type(fireHazard(S2, SpParamsMED, exampleforestMED), "double")
   expect_s3_class(plot(S2, "SoilPlantConductance"), "ggplot")
   expect_s3_class(plot(S2, "LeafPsiMin"), "ggplot")
   expect_s3_class(plot(S2, "LeafPsiMax"), "ggplot")
@@ -202,6 +205,7 @@ test_that("Can produce all advanced spwb_day plots",{
                 latitude = 41.82592, elevation = 100, slope=0, aspect=0,
                 prec = examplemeteo$Precipitation[d1])
   expect_s3_class(sd2, "spwb_day")
+  expect_type(fireHazard(sd2, SpParamsMED, exampleforestMED), "double")
   expect_s3_class(plot(sd2, "LeafPsi"), "ggplot")
   expect_s3_class(plot(sd2, "LeafPsiAverage"), "ggplot")
   expect_s3_class(plot(sd2, "RootPsi"), "ggplot")
@@ -245,6 +249,8 @@ test_that("Can produce all basic growth plots and summaries",{
   G1<-growth(x1, examplemeteo[d,], latitude = 41.82592, elevation = 100)
   expect_s3_class(G1, "growth")
   
+  expect_type(fireHazard(G1, SpParamsMED, exampleforestMED), "double")
+  expect_s3_class(plot(G1, "CarbonBalance"), "ggplot")
   expect_s3_class(plot(G1, "BiomassBalance"), "ggplot")
   expect_s3_class(plot(G1, "GrossPhotosynthesis"), "ggplot")
   expect_s3_class(plot(G1, "MaintenanceRespiration"), "ggplot")
@@ -268,6 +274,7 @@ test_that("Can produce all basic growth plots and summaries",{
   expect_s3_class(plot(G1, "SAgrowth"), "ggplot")
   expect_s3_class(plot(G1, "LAgrowth"), "ggplot")
   expect_s3_class(plot(G1, "HuberValue"), "ggplot")
+  expect_type(summary(G1, output = "CarbonBalance"), "double")
   expect_type(summary(G1, output = "LabileCarbonBalance$GrossPhotosynthesis"), "double")
   expect_type(summary(G1, output = "MaintenanceRespiration"), "double")
   expect_type(summary(G1, output = "GrowthCosts"), "double")
@@ -278,8 +285,6 @@ test_that("Can produce all basic growth plots and summaries",{
   expect_type(summary(G1, output = "SugarSapwood"), "double")
   expect_type(summary(G1, output = "StarchSapwood"), "double")
   expect_type(summary(G1, output = "SugarTransport"), "double")
-  expect_type(summary(G1, output = "LeafPI0"), "double")
-  expect_type(summary(G1, output = "StemPI0"), "double")
   expect_type(summary(G1, output = "LeafArea"), "double")
   expect_type(summary(G1, output = "SapwoodArea"), "double")
   expect_type(summary(G1, output = "FineRootBiomass"), "double")
@@ -299,11 +304,10 @@ test_that("Can produce all advanced growth plots and summaries",{
   expect_s3_class(x2, "growthInput")
   G2<-growth(x2, examplemeteo[d,], latitude = 41.82592, elevation = 100)
   expect_s3_class(G2, "growth")
+  expect_type(fireHazard(G2, SpParamsMED, exampleforestMED), "double")
   expect_s3_class(plot(G2, "FineRootArea"), "ggplot")
   expect_s3_class(plot(G2, "FRAgrowth"), "ggplot")
   expect_s3_class(plot(G2, "RootAreaLeafArea"), "ggplot")
-  expect_s3_class(plot(G2, "LeafPI0"), "ggplot")
-  expect_s3_class(plot(G2, "StemPI0"), "ggplot")
   expect_type(summary(G2, output = "FineRootArea"), "double")
   expect_type(summary(G2, output = "FRAgrowth"), "double")
   expect_type(droughtStress(G2, index = "ADS", draw=FALSE), "double")
@@ -316,6 +320,7 @@ test_that("Can produce all advanced subdaily growth plots",{
   control = defaultControl("Sperry")
   control$verbose = FALSE
   control$subdailyResults = TRUE
+  control$subdailyCarbonBalance = TRUE
   x2 = forest2growthInput(exampleforestMED,examplesoil, SpParamsMED, control)
   expect_s3_class(x2, "growthInput")
   G2<-growth(x2, examplemeteo[d,], latitude = 41.82592, elevation = 100)
@@ -348,6 +353,7 @@ test_that("Can produce all advanced subdaily growth plots",{
 test_that("Can produce all advanced growth_day plots",{
   control = defaultControl("Sperry")
   control$verbose = FALSE
+  control$subdailyCarbonBalance = TRUE
   x2 = forest2growthInput(exampleforestMED,examplesoil, SpParamsMED, control)
   expect_s3_class(x2, "growthInput")
   d1 = d[1]
@@ -358,6 +364,7 @@ test_that("Can produce all advanced growth_day plots",{
                 latitude = 41.82592, elevation = 100, slope=0, aspect=0,
                 prec = examplemeteo$Precipitation[d1])
   expect_s3_class(sd2, "growth_day")
+  expect_type(fireHazard(sd2, SpParamsMED, exampleforestMED), "double")
   expect_s3_class(plot(sd2, "GrossPhotosynthesis"), "ggplot")
   expect_s3_class(plot(sd2, "MaintenanceRespiration"), "ggplot")
   expect_s3_class(plot(sd2, "RootExudation"), "ggplot")
